==> jc-1.4.0.tar.gz: java/awt/image/Kernel.h <==
// public class java.awt.image.Kernel

// class file dependencies
// @dep_class 6880c39063c868ae java_awt_image_Kernel
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_Kernel_H_
#define _JC_java_awt_image_Kernel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_image_Kernel$sub_refs	_jc_java_awt_image_Kernel$sub_refs;
typedef struct _jc_java_awt_image_Kernel$sub_nonrefs	_jc_java_awt_image_Kernel$sub_nonrefs;
typedef struct _jc_java_awt_image_Kernel$refs	_jc_java_awt_image_Kernel$refs;
typedef struct _jc_java_awt_image_Kernel$nonrefs	_jc_java_awt_image_Kernel$nonrefs;
typedef struct _jc_java_awt_image_Kernel$object	_jc_java_awt_image_Kernel$object;

typedef const struct _jc_java_awt_image_Kernel$vmethods	_jc_java_awt_image_Kernel$vmethods;
typedef const struct _jc_java_awt_image_Kernel$vtable	_jc_java_awt_image_Kernel$vtable;
typedef const struct _jc_java_awt_image_Kernel$vtype	_jc_java_awt_image_Kernel$vtype;

// Constructors
extern void _jc_java_awt_image_Kernel$method$_init$01e7c638e6fe752c(_jc_env *, struct _jc_java_awt_image_Kernel$object *, jint, jint, struct _jc_float_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_image_Kernel$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
extern jint _jc_java_awt_image_Kernel$method$getHeight$68727004cbd10139(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
extern _jc_float_array *_jc_java_awt_image_Kernel$method$getKernelData$da5a410236e8f8f2(_jc_env *, struct _jc_java_awt_image_Kernel$object *, struct _jc_float_array *);
extern jint _jc_java_awt_image_Kernel$method$getWidth$0d702aea89749e0c(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
extern jint _jc_java_awt_image_Kernel$method$getXOrigin$d06cf65a8b9d4f18(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
extern jint _jc_java_awt_image_Kernel$method$getYOrigin$394da917a39dcdf2(_jc_env *, struct _jc_java_awt_image_Kernel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_Kernel$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getHeight$68727004cbd10139;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getKernelData$da5a410236e8f8f2;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getWidth$0d702aea89749e0c;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getXOrigin$d06cf65a8b9d4f18;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getYOrigin$394da917a39dcdf2;

// Virtual methods structure
struct _jc_java_awt_image_Kernel$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
	jint	(*getHeight$68727004cbd10139)(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
	_jc_float_array	*(*getKernelData$da5a410236e8f8f2)(_jc_env *, struct _jc_java_awt_image_Kernel$object *, struct _jc_float_array *);
	jint	(*getWidth$0d702aea89749e0c)(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
	jint	(*getXOrigin$d06cf65a8b9d4f18)(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
	jint	(*getYOrigin$394da917a39dcdf2)(_jc_env *, struct _jc_java_awt_image_Kernel$object *);
};

// Vtable
struct _jc_java_awt_image_Kernel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_Kernel$vmethods	java_awt_image_Kernel;
};

// Vtype
struct _jc_java_awt_image_Kernel$vtype {
	_jc_type			type;
	_jc_java_awt_image_Kernel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_Kernel$sub_refs {
	_jc_float_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_Kernel$refs {
    _jc_java_awt_image_Kernel$sub_refs	java_awt_image_Kernel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_Kernel$sub_nonrefs {
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_Kernel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_Kernel$sub_nonrefs	java_awt_image_Kernel;
};

// Object instance structure
struct _jc_java_awt_image_Kernel$object {
	_jc_java_awt_image_Kernel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_Kernel$vtype	*vtype;
	_jc_java_awt_image_Kernel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_Kernel$vtype _jc_java_awt_image_Kernel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_Kernel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_Kernel$class_object;

#endif	/* _JC_java_awt_image_Kernel_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/Kernel.h <==
// public class java.awt.image.Kernel

// class file dependencies
// @dep_class 6880c39063c868ae java_awt_image_Kernel
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_Kernel_H_
#define _JC_java_awt_image_Kernel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_image_Kernel$sub_refs	_jc_java_awt_image_Kernel$sub_refs;
typedef struct _jc_java_awt_image_Kernel$sub_nonrefs	_jc_java_awt_image_Kernel$sub_nonrefs;
typedef struct _jc_java_awt_image_Kernel$refs	_jc_java_awt_image_Kernel$refs;
typedef struct _jc_java_awt_image_Kernel$nonrefs	_jc_java_awt_image_Kernel$nonrefs;
typedef struct _jc_java_awt_image_Kernel$object	_jc_java_awt_image_Kernel$object;

typedef const struct _jc_java_awt_image_Kernel$vmethods	_jc_java_awt_image_Kernel$vmethods;
typedef const struct _jc_java_awt_image_Kernel$vtable	_jc_java_awt_image_Kernel$vtable;
typedef const struct _jc_java_awt_image_Kernel$vtype	_jc_java_awt_image_Kernel$vtype;

// Constructors
extern void _jc_java_awt_image_Kernel$method$_init$01e7c638e6fe752c(_jc_env *, struct _jc_java_awt_image_Kernel$object *, jint, jint, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_image_Kernel$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_image_Kernel$method$getHeight$68727004cbd10139(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_java_awt_image_Kernel$method$getKernelData$da5a410236e8f8f2(_jc_env *, struct _jc_java_awt_image_Kernel$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_image_Kernel$method$getWidth$0d702aea89749e0c(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_image_Kernel$method$getXOrigin$d06cf65a8b9d4f18(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_image_Kernel$method$getYOrigin$394da917a39dcdf2(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_Kernel$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getHeight$68727004cbd10139;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getKernelData$da5a410236e8f8f2;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getWidth$0d702aea89749e0c;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getXOrigin$d06cf65a8b9d4f18;
extern _jc_method _jc_java_awt_image_Kernel$method_info$getYOrigin$394da917a39dcdf2;

// Virtual methods structure
struct _jc_java_awt_image_Kernel$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
	jint	(*getHeight$68727004cbd10139)(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
	_jc_float_array	*(*getKernelData$da5a410236e8f8f2)(_jc_env *, struct _jc_java_awt_image_Kernel$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	jint	(*getWidth$0d702aea89749e0c)(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
	jint	(*getXOrigin$d06cf65a8b9d4f18)(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
	jint	(*getYOrigin$394da917a39dcdf2)(_jc_env *, struct _jc_java_awt_image_Kernel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_Kernel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_Kernel$vmethods	java_awt_image_Kernel;
};

// Vtype
struct _jc_java_awt_image_Kernel$vtype {
	_jc_type			type;
	_jc_java_awt_image_Kernel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_Kernel$sub_refs {
	_jc_float_array	*data;
};

// Reference instance fields (object)
struct _jc_java_awt_image_Kernel$refs {
    _jc_java_awt_image_Kernel$sub_refs	java_awt_image_Kernel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_Kernel$sub_nonrefs {
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_Kernel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_Kernel$sub_nonrefs	java_awt_image_Kernel;
};

// Object instance structure
struct _jc_java_awt_image_Kernel$object {
	_jc_java_awt_image_Kernel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_Kernel$vtype	*vtype;
	_jc_java_awt_image_Kernel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_Kernel$vtype _jc_java_awt_image_Kernel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_Kernel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_Kernel$class_object;

#endif	/* _JC_java_awt_image_Kernel_H_ */
